#include <gnome.h>



void
on_quit1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cut1_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_copy1_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_paste1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_preferences1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about2_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_properties2_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_delete1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_host_edit_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_new_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_delete_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_refresh_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_host_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_where_used_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_env_choose_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_edit_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_new_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_where_used_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_delete_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_refresh_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_new_var_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_del_var_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_up_var_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_down_var_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_var_top_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_env_var_bottom_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_env_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_show_hosts_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_show_environments_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_application_main_delete_event       (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_certificate_save_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_upload_certificate_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_host_view_certificate_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_cal_list_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_cal_close_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_list_year_prev_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_list_year_next_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_refresh_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_cut_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_copy_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_paste_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_delete_clicked           (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_treeview_cal_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_cal_popup_menu             (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_host_list_edit_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_host_list_new_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_host_list_references_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_host_list_delete_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_edit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_new_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_references_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_env_list_delete_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_treeview_hosts_button_press_event   (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_hosts_popup_menu           (GtkWidget       *widget,
                                        gpointer         user_data);

gboolean
on_treeview_environments_button_press_event
                                        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

gboolean
on_treeview_environments_popup_menu    (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_cal_menu_edit_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_new_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_cut_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_copy_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_paste_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_delete_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_cal_menu_references_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_cal_new_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_cal_new_question_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_cal_folder_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_edit_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_year_prev_preview_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_year_next_preview_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancelbutton_cal_calendar_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_cal_calendar_clicked       (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_cal_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_cal_copy_formula_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_where_used_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_show_calendars_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_dialog_host_list_delete_event       (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_host_list_close_clicked      (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_env_list_delete_event        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_button_env_list_close_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_location_bar_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoomin_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_zoomout_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_normal_size_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_status_bar_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_show_grid_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_snap_to_grid_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_eventbox_main_navigator_button_press_event
                                        (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_button_main_zoom_out_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_main_zoom_in_clicked         (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_canvas_main_scroll_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_refresh_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_toolbutton_refresh_clicked          (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_entry_main_location_activate        (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_button_find_select_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_find_close_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_find_activate                 (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_button_find_find_clicked            (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_find_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_toolbutton_find_clicked             (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_find_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_delete1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_entry_pref_database_server_changed  (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_entry_pref_database_server_changed  (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_entry_pref_database_name_changed    (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_fileentry_database_socket_changed   (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_combobox_pref_grid_style_changed    (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_colorbutton_pref_grid_color_color_set
                                        (GtkColorButton  *colorbutton,
                                        gpointer         user_data);

void
on_spinbutton_pref_grid_width_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinbutton_pref_grid_height_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinbutton_pref_cal_num_month_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_combobox_pref_cal_first_day_changed (GtkComboBox     *combobox,
                                        gpointer         user_data);

void
on_fontbutton_pref_cal_font_font_set   (GtkFontButton   *fontbutton,
                                        gpointer         user_data);

void
on_radiobutton_pref_cal_font_theme_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_dialog_preferences_delete_event     (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_closebutton_pref_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_entry_pref_database_username_changed
                                        (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_spinbutton_pref_database_port_value_changed
                                        (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_button_pref_database_revert_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_pref_database_test_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_database_test_connect_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_database_assistant_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_login1_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_logout1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_button_login_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_druid_connect_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_druidpagefinish1_finish             (GnomeDruidPage  *gnomedruidpage,
                                        GtkWidget       *widget,
                                        gpointer         user_data);

void
on_button_pref_grid_ratio_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_bg_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkbutton_bg_hierarchy_toggled    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_spinbutton_bg_height_value_changed  (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinbutton_bg_width_value_changed   (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_button_bg_ratio_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_bg_delete_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_bg_upload_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_bg_save_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_background_new_job_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_background_new_jobset_activate      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_background_change_canvas_properties_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_checkbutton_job_h_host_toggled      (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_time_toggled      (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_start_limit_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_max_duration_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_calendar_toggled  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_job_arg_new_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_arg_del_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_arg_up_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_arg_down_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_arg_top_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_arg_bottom_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkbutton_job_h_arg_toggled       (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_command_toggled   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_stdout_toggled    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_stderr_toggled    (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_ret_toggled       (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_username_toggled  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_loadenv_toggled   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_env_loadparent_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_job_file_add_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_file_remove_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_env_choose_destroy_event     (GtkObject       *object,
                                        gpointer         user_data);


void
on_checkbutton_job_icon_h_default_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_icon_h_waiting_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_icon_h_running_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_icon_h_completed_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_icon_h_failed_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_job_icon_default_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_waiting_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_running_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_completed_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_failed_save_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_default_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_waiting_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_running_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_completed_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_icon_failed_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkbutton_jobset_icon_h_default_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_jobset_icon_h_waiting_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_jobset_icon_h_running_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_jobset_icon_h_completed_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_jobset_icon_h_failed_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_jobset_icon_default_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_waiting_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_running_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_completed_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_failed_save_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_default_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_waiting_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_running_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_completed_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_jobset_icon_failed_upload_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_job_calendar_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_cal_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_okbutton_job_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_default_job_parameters1_activate    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_completed1_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_failed1_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_running1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_waiting1_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_completed_or_failed1_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_statistics1_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_completed2_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_failed2_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_running2_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_waiting2_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_completed_or_failed2_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_delete2_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_toolbutton_delete_clicked           (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_delete3_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_toolbutton_cut_clicked              (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_toolbutton_copy_clicked             (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_toolbutton_paste_clicked            (GtkToolButton   *toolbutton,
                                        gpointer         user_data);

void
on_cut2_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_copy2_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_background_paste_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_checkbutton_job_h_retries_toggled   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_job_h_retries_interval_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);
